@@ -1,3 +1,4 @@
+
 //
 //  PushTalkPlugin.m
 //  PushTalk
@@ -38,6 +39,10 @@
 
 @implementation JPushPlugin
 
+-(void)startJPushSDK:(CDVInvokedUrlCommand*)command{
+    [(AppDelegate*)[UIApplication sharedApplication].delegate startJPushSDK];
+}
+
 #pragma mark- 外部接口
 -(void)stopPush:(CDVInvokedUrlCommand*)command{
     [[UIApplication sharedApplication]unregisterForRemoteNotifications];
@@ -60,7 +65,7 @@
 
 - (void)pluginInitialize {
     NSLog(@"### pluginInitialize ");
-    SharedJPushPlugin = self;
+    [self initPlugin];
 }
 
 #else
@@ -69,11 +74,22 @@
     NSLog(@"### initWithWebView ");
     if (self=[super initWithWebView:theWebView]) {
     }
+    [self initPlugin];
     return self;
 }
 
 #endif
 
+-(void)initPlugin{
+    if (!SharedJPushPlugin) {
+        SharedJPushPlugin = self;
+    }
+    [[NSNotificationCenter defaultCenter] addObserver:self
+                                             selector:@selector(networkDidReceiveMessage:)
+                                                 name:kJPFNetworkDidReceiveMessageNotification
+                                               object:nil];
+}
+
 -(void)jpushFireDocumentEvent:(NSString*)eventName jsString:(NSString*)jsString{
     dispatch_async(dispatch_get_main_queue(), ^{
         [self.commandDelegate evalJs:[NSString stringWithFormat:@"cordova.fireDocumentEvent('jpush.%@',%@)", eventName, jsString]];
